<?php
namespace Teknisa\CTB\Services;

use Teknisa\Libs\Util\Environment;
use Teknisa\CTB\Factories\Ger17900LucroPresumidoFactory;

class Ger17900LucroPresumidoService {

  protected $nrorg;
  protected $environment;
  protected $factory;

  public function __construct(Environment $environment, Ger17900LucroPresumidoFactory $factory) {
    $this->environment = $environment;
    $this->nrorg = $this->environment->getNrOrg();
    $this->factory = $factory;
  }

  public function validateRegy672Empr($row) {
  
    if (!\Zeedhi\Framework\Util\Functions::arrayKeyExists('CDEMPRESA', $row) || !\Zeedhi\Framework\Util\Functions::arrayKeyExists('DTREFERENCIA', $row)
        || !\Zeedhi\Framework\Util\Functions::arrayKeyExists('IDTIPO', $row) || !\Zeedhi\Framework\Util\Functions::arrayKeyExists('IDTIPO', $row))
      throw new \Exception('Campos obrigatórios vazios!');
    if (ctype_space($row['CDEMPRESA']) || ctype_space($row['DTREFERENCIA'])
        || ctype_space($row['IDTIPO']))
      throw new \Exception('Campos obrigatórios vazios!');
    if (!preg_match('/^31\/12\/\d{4}$/', $row['DTREFERENCIA']))
      throw new \Exception('Data de referência inválida!');
    if (explode('/', $row['DTREFERENCIA'])[2] < 2014)
      throw new \Exception('Ano de referência deve ser 2014 ou após!');
    if ($row['VRREGY672EMPR'] !== null && $row['IDTIPO'] !== 'V')
      throw new \Exception('O valor só deve ser especificado quando selecionado o tipo Valor');
    if ($row['VRREGY672EMPR'] !== NULL && is_nan($row['VRREGY672EMPR']) )
      throw new \Exception('O valor especificado deve ser numérico!');
    $regy672emprExists = $this->factory->verificaRegy672Empr(array(
      "NRSEQY672" => $row['NRSEQY672'],
      "CDEMPRESA" => $row['CDEMPRESA'],
      "DTREFERENCIA" => $row['DTREFERENCIA'],
      "NRORG" => $this->nrorg
    ));
    if($regy672emprExists && $row['__is_new'])
      throw new \Exception('O registro já existe!');

  }



  public function validateRegy672Contctbl($row) {
    if (!\Zeedhi\Framework\Util\Functions::arrayKeyExists('CDCONTCTBL', $row) || !\Zeedhi\Framework\Util\Functions::arrayKeyExists('NRSEQY672EMPR', $row))
      throw new \Exception('Campos obrigatórios vazios!');
    if (ctype_space($row['CDCONTCTBL']))
      throw new \Exception('Campos obrigatórios vazios!');
    $relacaoExists = $this->factory->verificaRegy672Contctbl(array(
      "CDCONTCTBL" => $row['CDCONTCTBL'],
      "NRSEQY672EMPR" => $row['NRSEQY672EMPR'],
      "NRORG" => $this->nrorg
    ));
    if ($relacaoExists) {
      throw new \Exception('Esta conta já está associada ao registro!');
    }
  }



  public function deleteRegy672Empr($row) {

    $this->factory->deleteRegy672Children($row['NRSEQUENCIAL']);
    $this->factory->deleteRegy672Empr($row['NRSEQUENCIAL']);

  }

}